@@ -39,8 +39,6 @@
 #include <locale.h>
 #include <gettext.h>
 #define _(String) gettext (String)
-#define gettext_noop(String) String
-#define N_(String) gettext_noop (String)
 
 #include <shishi.h>
 
@@ -57,8 +55,8 @@ main (int argc, char *argv[])
 {
   struct gengetopt_args_info args;
   Shishi *sh;
-  char *infile = NULL;
-  char *outfile = NULL;
+  const char *infile = NULL;
+  const char *outfile = NULL;
   int rc;
 
   setlocale (LC_ALL, "");
